@@ -500,15 +500,7 @@ class Instance(Model):
                 if isinstance(v, UnknownExpression) or k in data:
                     fragments.append(f"{k} = {v};\n")
                 elif isinstance(v, EnumMeta):
-                    enumDecl = k + " = {"
-                    first = True
-                    for mem in v.__members__:
-                        if not first:
-                            enumDecl += ", "
-                        enumDecl += "'" + str(mem) + "'"
-                        first = False
-                    enumDecl += "};"
-                    fragments.append(enumDecl)
+                    data[k] = [str(mem) for mem in v.__members__]
                 else:
                     data[k] = v
             fragments.extend(inst._code_fragments)
@@ -523,7 +515,9 @@ class Instance(Model):
                     prefix="mzn_data", suffix=".json", delete=False
                 )
                 gen_files.append(file)
-                file.write(json.dumps(data, cls=MZNJSONEncoder).encode())
+                file.write(
+                    json.dumps(data, cls=MZNJSONEncoder, ensure_ascii=False).encode()
+                )
                 file.close()
                 files.append(Path(file.name))
             if len(fragments) > 0 or len(files) == 0:
@@ -758,9 +752,9 @@ class Instance(Model):
                 tmp["_checker"] = statistics.pop("_checker")
 
             solution = self.output_type(**tmp)
-            statistics["time"] = obj["time"]
+            statistics["time"] = timedelta(milliseconds=obj["time"])
         elif obj["type"] == "time":
-            statistics["time"] = obj["time"]
+            statistics["time"] = timedelta(milliseconds=obj["time"])
         elif obj["type"] == "statistics":
             for key, val in obj["statistics"].items():
                 set_stat(statistics, key, str(val))
@@ -803,6 +797,10 @@ def _to_python_type(mzn_type: dict) -> Type:
         pytype = str
     elif basetype == "ann":
         pytype = str
+    elif basetype == "tuple":
+        pytype = list
+    elif basetype == "record":
+        pytype = dict
     else:
         warnings.warn(
             f"Unable to determine minizinc type `{basetype}` assuming integer type",
